# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""


from django.db import migrations, models
import django.db.models.deletion
import timezone_field.fields
import pipeline.models


class Migration(migrations.Migration):

    dependencies = [
        ("pipeline", "0016_auto_20181220_0958"),
    ]

    operations = [
        migrations.CreateModel(
            name="CrontabSchedule",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True,),),
                ("minute", models.CharField(default=b"*", max_length=64, verbose_name="minute"),),
                ("hour", models.CharField(default=b"*", max_length=64, verbose_name="hour"),),
                ("day_of_week", models.CharField(default=b"*", max_length=64, verbose_name="day of week"),),
                ("day_of_month", models.CharField(default=b"*", max_length=64, verbose_name="day of month"),),
                ("month_of_year", models.CharField(default=b"*", max_length=64, verbose_name="month of year"),),
                ("timezone", timezone_field.fields.TimeZoneField(default=b"UTC")),
            ],
            options={
                "ordering": ["month_of_year", "day_of_month", "day_of_week", "hour", "minute",],
                "verbose_name": "crontab",
                "verbose_name_plural": "crontabs",
            },
        ),
        migrations.CreateModel(
            name="DjCeleryPeriodicTask",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True,),),
                (
                    "name",
                    models.CharField(help_text="Useful description", unique=True, max_length=200, verbose_name="name",),
                ),
                ("task", models.CharField(max_length=200, verbose_name="task name")),
                (
                    "args",
                    models.TextField(
                        default=b"[]",
                        help_text="JSON encoded positional arguments",
                        verbose_name="Arguments",
                        blank=True,
                    ),
                ),
                (
                    "kwargs",
                    models.TextField(
                        default=b"{}",
                        help_text="JSON encoded keyword arguments",
                        verbose_name="Keyword arguments",
                        blank=True,
                    ),
                ),
                (
                    "queue",
                    models.CharField(
                        default=None,
                        max_length=200,
                        blank=True,
                        help_text="Queue defined in CELERY_QUEUES",
                        null=True,
                        verbose_name="queue",
                    ),
                ),
                (
                    "exchange",
                    models.CharField(default=None, max_length=200, null=True, verbose_name="exchange", blank=True,),
                ),
                (
                    "routing_key",
                    models.CharField(default=None, max_length=200, null=True, verbose_name="routing key", blank=True,),
                ),
                ("expires", models.DateTimeField(null=True, verbose_name="expires", blank=True),),
                ("enabled", models.BooleanField(default=True, verbose_name="enabled")),
                ("last_run_at", models.DateTimeField(null=True, editable=False, blank=True),),
                ("total_run_count", models.PositiveIntegerField(default=0, editable=False),),
                ("date_changed", models.DateTimeField(auto_now=True)),
                ("description", models.TextField(verbose_name="description", blank=True),),
                (
                    "crontab",
                    models.ForeignKey(
                        blank=True,
                        to="periodic_task.CrontabSchedule",
                        help_text="Use one of interval/crontab",
                        null=True,
                        verbose_name="crontab",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={"verbose_name": "periodic task", "verbose_name_plural": "periodic tasks",},
        ),
        migrations.CreateModel(
            name="DjCeleryPeriodicTasks",
            fields=[
                ("ident", models.SmallIntegerField(default=1, unique=True, serialize=False, primary_key=True),),
                ("last_update", models.DateTimeField()),
            ],
        ),
        migrations.CreateModel(
            name="IntervalSchedule",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True,),),
                ("every", models.IntegerField(verbose_name="every")),
                (
                    "period",
                    models.CharField(
                        max_length=24,
                        verbose_name="period",
                        choices=[
                            (b"days", "Days"),
                            (b"hours", "Hours"),
                            (b"minutes", "Minutes"),
                            (b"seconds", "Seconds"),
                            (b"microseconds", "Microseconds"),
                        ],
                    ),
                ),
            ],
            options={"ordering": ["period", "every"], "verbose_name": "interval", "verbose_name_plural": "intervals",},
        ),
        migrations.CreateModel(
            name="PeriodicTask",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True,),),
                ("name", models.CharField(max_length=64, verbose_name="\u5468\u671f\u4efb\u52a1\u540d\u79f0",),),
                ("cron", models.CharField(max_length=128, verbose_name="\u8c03\u5ea6\u7b56\u7565"),),
                ("total_run_count", models.PositiveIntegerField(default=0, verbose_name="\u6267\u884c\u6b21\u6570"),),
                ("last_run_at", models.DateTimeField(null=True, verbose_name="\u4e0a\u6b21\u8fd0\u884c\u65f6\u95f4"),),
                ("creator", models.CharField(default=b"", max_length=32, verbose_name="\u521b\u5efa\u8005"),),
                ("extra_info", pipeline.models.CompressJSONField(verbose_name="\u989d\u5916\u4fe1\u606f", null=True),),
                (
                    "celery_task",
                    models.ForeignKey(
                        verbose_name="celery \u5468\u671f\u4efb\u52a1\u5b9e\u4f8b",
                        to="periodic_task.DjCeleryPeriodicTask",
                        null=True,
                        on_delete=models.SET_NULL,
                    ),
                ),
                (
                    "snapshot",
                    models.ForeignKey(
                        related_name="periodic_tasks",
                        verbose_name="\u7528\u4e8e\u521b\u5efa\u6d41\u7a0b\u5b9e\u4f8b\u7684\u7ed3\u6784\u6570\u636e",
                        to="pipeline.Snapshot",
                        on_delete=models.DO_NOTHING,
                    ),
                ),
                (
                    "template",
                    models.ForeignKey(
                        related_name="periodic_tasks",
                        on_delete=django.db.models.deletion.SET_NULL,
                        verbose_name="\u5468\u671f\u4efb\u52a1\u5bf9\u5e94\u7684\u6a21\u677f",
                        to_field="template_id",
                        to="pipeline.PipelineTemplate",
                        null=True,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="PeriodicTaskHistory",
            fields=[
                ("id", models.AutoField(verbose_name="ID", serialize=False, auto_created=True, primary_key=True,),),
                ("ex_data", models.TextField(verbose_name="\u5f02\u5e38\u4fe1\u606f")),
                ("start_at", models.DateTimeField(auto_now_add=True, verbose_name="\u5f00\u59cb\u65f6\u95f4"),),
                (
                    "start_success",
                    models.BooleanField(default=True, verbose_name="\u662f\u5426\u542f\u52a8\u6210\u529f",),
                ),
                (
                    "periodic_task",
                    models.ForeignKey(
                        related_name="instance_rel",
                        verbose_name="\u5468\u671f\u4efb\u52a1",
                        to="periodic_task.PeriodicTask",
                        null=True,
                        on_delete=models.DO_NOTHING,
                    ),
                ),
                (
                    "pipeline_instance",
                    models.ForeignKey(
                        related_name="periodic_task_rel",
                        verbose_name="Pipeline \u5b9e\u4f8b",
                        to_field="instance_id",
                        to="pipeline.PipelineInstance",
                        null=True,
                        on_delete=models.DO_NOTHING,
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="djceleryperiodictask",
            name="interval",
            field=models.ForeignKey(
                verbose_name="interval",
                blank=True,
                to="periodic_task.IntervalSchedule",
                null=True,
                on_delete=models.CASCADE,
            ),
        ),
    ]



# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from pipeline.engine import models
from pipeline.engine.conf.function_switch import FREEZE_ENGINE
from pipeline.engine.core import api
from pipeline.service import task_service


@admin.register(models.PipelineModel)
class PipelineModelAdmin(admin.ModelAdmin):
    list_display = ["id", "process"]
    search_fields = ["id__exact", "process__id__exact"]
    raw_id_fields = ["process"]


@admin.register(models.PipelineProcess)
class PipelineProcessAdmin(admin.ModelAdmin):
    list_display = [
        "id",
        "root_pipeline_id",
        "current_node_id",
        "destination_id",
        "parent_id",
        "need_ack",
        "ack_num",
        "is_alive",
        "is_sleep",
        "is_frozen",
    ]
    search_fields = ["id__exact", "root_pipeline_id__exact", "current_node_id__exact"]
    list_filter = ["is_alive", "is_sleep"]
    raw_id_fields = ["snapshot"]


def force_fail_node(modeladmin, request, queryset):
    for item in queryset:
        task_service.forced_fail(item.id)


@admin.register(models.Status)
class StatusAdmin(admin.ModelAdmin):
    list_display = [
        "id",
        "name",
        "state",
        "retry",
        "skip",
        "loop",
        "created_time",
        "started_time",
        "archived_time",
    ]
    search_fields = ["=id"]
    actions = [force_fail_node]


@admin.register(models.ScheduleService)
class ScheduleServiceAdmin(admin.ModelAdmin):
    list_display = [
        "id",
        "activity_id",
        "process_id",
        "schedule_times",
        "wait_callback",
        "is_finished",
    ]
    search_fields = ["id__exact"]
    list_filter = ["wait_callback", "is_finished"]


@admin.register(models.ProcessCeleryTask)
class ProcessCeleryTaskAdmin(admin.ModelAdmin):
    list_display = ["id", "process_id", "celery_task_id"]
    search_fields = ["id__exact", "process_id__exact"]


@admin.register(models.Data)
class DataAdmin(admin.ModelAdmin):
    list_display = ["id", "inputs", "outputs", "ex_data"]
    search_fields = ["id__exact"]


@admin.register(models.HistoryData)
class HistoryDataAdmin(admin.ModelAdmin):
    list_display = ["id", "inputs", "outputs", "ex_data"]
    search_fields = ["id__exact"]


@admin.register(models.History)
class HistoryAdmin(admin.ModelAdmin):
    list_display = ["identifier", "started_time", "archived_time"]
    search_fields = ["identifier__exact"]
    raw_id_fields = ["data"]


@admin.register(models.ScheduleCeleryTask)
class ScheduleCeleryTaskAdmin(admin.ModelAdmin):
    list_display = ["schedule_id", "celery_task_id"]
    search_fields = ["schedule_id__exact"]


@admin.register(models.NodeCeleryTask)
class NodeCeleryTaskAdmin(admin.ModelAdmin):
    list_display = ["node_id", "celery_task_id"]
    search_fields = ["node_id__exact"]


on = True
off = False

switch_hook = {FREEZE_ENGINE: {on: api.freeze, off: api.unfreeze}}


def turn_on_function(modeladmin, request, queryset):
    for item in queryset:
        if not item.is_active:
            switch_hook[item.name][on]()


def turn_off_function(modeladmin, request, queryset):
    for item in queryset:
        if item.is_active:
            switch_hook[item.name][off]()


turn_on_function.short_description = _("打开所选的功能")
turn_off_function.short_description = _("关闭所选的功能")


@admin.register(models.FunctionSwitch)
class FunctionAdmin(admin.ModelAdmin):
    list_display = ["name", "description", "is_active"]
    search_fields = ["name", "description"]
    actions = [turn_on_function, turn_off_function]

    def has_delete_permission(self, request, obj=None):
        return False

    def get_actions(self, request):
        actions = super(FunctionAdmin, self).get_actions(request)
        if "delete_selected" in actions:
            del actions["delete_selected"]
        return actions

    def get_readonly_fields(self, request, obj=None):
        if obj:  # obj is not None, so this is an edit
            return [
                "name",
                "is_active",
            ]  # Return a list or tuple of readonly fields' names
        else:  # This is an addition
            return []


def resend_task(modeladmin, request, queryset):
    for item in queryset:
        item.resend()


@admin.register(models.SendFailedCeleryTask)
class SendFailedCeleryTaskAdmin(admin.ModelAdmin):
    list_display = [
        "id",
        "name",
        "kwargs",
        "type",
        "extra_kwargs",
        "exec_trace",
        "created_at",
    ]
    search_fields = ["id__exact", "name"]
    actions = [resend_task]



# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""

import logging

from django.utils.module_loading import import_string

from pipeline.conf import default_settings
from pipeline.engine.models import PipelineProcess

logger = logging.getLogger("celery")


def get_healer():
    if not default_settings.ENGINE_ZOMBIE_PROCESS_DOCTORS:
        logger.info("ENGINE_ZOMBIE_PROCESS_DOCTORS settings is empty, use dummy healer")
        return DummyZombieProcHealer()

    doctors = []

    for dr_setting in default_settings.ENGINE_ZOMBIE_PROCESS_DOCTORS:
        try:
            doctors.append(import_string(dr_setting["class"])(**dr_setting["config"]))
        except Exception:
            logger.exception("Error occurred when init doctor({}), skip".format(dr_setting))

    if not doctors:
        logger.info("All doctor init failed, use dummy healer")
        return DummyZombieProcHealer()

    return ZombieProcHealer(doctors=doctors)


class DummyZombieProcHealer(object):
    def heal(self):
        pass


class ZombieProcHealer(object):
    def __init__(self, doctors):
        self.doctors = doctors

    def heal(self):

        if not self.doctors:
            return

        proc_ids = self._get_process_ids()

        for proc_id in proc_ids:

            # get proc every time for latest state
            proc = PipelineProcess.objects.get(id=proc_id)

            if not proc.is_alive or proc.is_frozen:
                continue

            for dr in self.doctors:
                if dr.confirm(proc):
                    dr.cure(proc)
                    break

    def _get_process_ids(self):
        return PipelineProcess.objects.filter(is_alive=True, is_frozen=False).values_list("id", flat=True)



# Generated by Django 2.2.19 on 2021-06-07 12:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pipeline", "0029_templaterelationship_always_use_latest"),
    ]

    operations = [
        migrations.AlterField(
            model_name="templaterelationship",
            name="descendant_template_id",
            field=models.CharField(db_index=True, max_length=32, verbose_name="子流程模板ID"),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.23 on 2019-12-13 08:19
from __future__ import unicode_literals

import timezone_field.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("periodic_task", "0002_auto_20190103_1918"),
    ]

    operations = [
        migrations.AddField(
            model_name="periodictask",
            name="priority",
            field=models.IntegerField(default=100, verbose_name="流程优先级"),
        ),
        migrations.AddField(
            model_name="periodictask",
            name="queue",
            field=models.CharField(default="", max_length=512, verbose_name="流程使用的队列名"),
        ),
        migrations.AlterField(
            model_name="crontabschedule",
            name="day_of_month",
            field=models.CharField(
                default="*", max_length=64, verbose_name="day of month"
            ),
        ),
        migrations.AlterField(
            model_name="crontabschedule",
            name="day_of_week",
            field=models.CharField(
                default="*", max_length=64, verbose_name="day of week"
            ),
        ),
        migrations.AlterField(
            model_name="crontabschedule",
            name="hour",
            field=models.CharField(default="*", max_length=64, verbose_name="hour"),
        ),
        migrations.AlterField(
            model_name="crontabschedule",
            name="minute",
            field=models.CharField(default="*", max_length=64, verbose_name="minute"),
        ),
        migrations.AlterField(
            model_name="crontabschedule",
            name="month_of_year",
            field=models.CharField(
                default="*", max_length=64, verbose_name="month of year"
            ),
        ),
        migrations.AlterField(
            model_name="crontabschedule",
            name="timezone",
            field=timezone_field.fields.TimeZoneField(default="UTC"),
        ),
        migrations.AlterField(
            model_name="djceleryperiodictask",
            name="args",
            field=models.TextField(
                blank=True,
                default="[]",
                help_text="JSON encoded positional arguments",
                verbose_name="Arguments",
            ),
        ),
        migrations.AlterField(
            model_name="djceleryperiodictask",
            name="kwargs",
            field=models.TextField(
                blank=True,
                default="{}",
                help_text="JSON encoded keyword arguments",
                verbose_name="Keyword arguments",
            ),
        ),
        migrations.AlterField(
            model_name="intervalschedule",
            name="period",
            field=models.CharField(
                choices=[
                    ("days", "Days"),
                    ("hours", "Hours"),
                    ("minutes", "Minutes"),
                    ("seconds", "Seconds"),
                    ("microseconds", "Microseconds"),
                ],
                max_length=24,
                verbose_name="period",
            ),
        ),
        migrations.AlterField(
            model_name="periodictask",
            name="creator",
            field=models.CharField(default="", max_length=32, verbose_name="创建者"),
        ),
    ]



# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""

from django.db import models, transaction
from django.utils.translation import ugettext_lazy as _

from pipeline.engine.models.fields import IOField


class DataSnapshotManager(models.Manager):
    def set_object(self, key, obj):
        # do not use update_or_create, prevent of deadlock
        with transaction.atomic():
            if self.get_object(key):
                self.filter(key=key).update(obj=obj)
            else:
                self.create(key=key, obj=obj)
        return True

    def get_object(self, key):
        try:
            return self.get(key=key).obj
        except DataSnapshot.DoesNotExist:
            return None

    def del_object(self, key):
        try:
            self.get(key=key).delete()
            return True
        except DataSnapshot.DoesNotExist:
            return False


class DataSnapshot(models.Model):
    key = models.CharField(_("对象唯一键"), max_length=255, primary_key=True)
    obj = IOField(verbose_name=_("对象存储字段"))

    objects = DataSnapshotManager()



# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""

import logging

from django.apps import AppConfig
from django.db.utils import OperationalError, ProgrammingError

from pipeline.conf import settings
from pipeline.utils.register import autodiscover_collections
from pipeline.variable_framework import context

logger = logging.getLogger("root")


class VariableFrameworkConfig(AppConfig):
    name = "pipeline.variable_framework"
    verbose_name = "PipelineVariableFramework"

    def ready(self):
        """
        @summary: 注册公共部分和RUN_VER下的变量到数据库
        @return:
        """
        from pipeline.variable_framework.signals.handlers import pre_variable_register_handler  # noqa

        for path in settings.VARIABLE_AUTO_DISCOVER_PATH:
            autodiscover_collections(path)

        if context.skip_update_var_models():
            return

        from pipeline.variable_framework.models import VariableModel
        from pipeline.core.data.library import VariableLibrary

        try:
            print("update variable models")
            VariableModel.objects.exclude(code__in=list(VariableLibrary.variables.keys())).update(status=False)
            print("update variable models finish")
        except (ProgrammingError, OperationalError) as e:
            # first migrate
            logger.exception(e)



# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""

from django.utils import timezone


class Stack(list):
    def top(self):
        return self[len(self) - 1]

    def push(self, item):
        self.append(item)


class ConstantDict(dict):
    """ConstantDict is a subclass of :class:`dict`, implementing __setitem__
    method to avoid item assignment::

    >>> d = ConstantDict({'key': 'value'})
    >>> d['key'] = 'value'
    Traceback (most recent call last):
        ...
    TypeError: 'ConstantDict' object does not support item assignment
    """

    def __setitem__(self, key, value):
        raise TypeError("'%s' object does not support item assignment" % self.__class__.__name__)


def calculate_elapsed_time(started_time, archived_time):
    """
    @summary: 计算节点耗时
    @param started_time: 执行开始时间
    @param archived_time: 执行结束时间
    @return:
    """
    if archived_time and started_time:
        elapsed_time = (archived_time - started_time).total_seconds()
    elif started_time:
        elapsed_time = (timezone.now() - started_time).total_seconds()
    else:
        elapsed_time = 0
    return round(elapsed_time)


class ActionResult(object):
    def __init__(self, result, message, extra=None):
        self.result = result
        self.message = message
        self.extra = extra



# Generated by Django 2.2.19 on 2021-08-12 09:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("engine", "0027_sendfailedcelerytask"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pipelineprocess",
            name="parent_id",
            field=models.CharField(db_index=True, default="", max_length=32, verbose_name="父 process 的 ID"),
        ),
    ]



# -*- coding: utf-8 -*-
"""
Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
Edition) available.
Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://opensource.org/licenses/MIT
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""
# Generated by Django 1.11.2 on 2017-11-24 10:43


from django.db import migrations, models
import django.db.models.deletion
import pipeline.models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="PipelineInstance",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("instance_id", models.CharField(max_length=32, unique=True, verbose_name="\u5b9e\u4f8bID")),
                (
                    "name",
                    models.CharField(
                        default="\u9ed8\u8ba4\u5b9e\u4f8b", max_length=64, verbose_name="\u5b9e\u4f8b\u540d\u79f0"
                    ),
                ),
                ("creator", models.CharField(max_length=32, verbose_name="\u521b\u5efa\u8005")),
                ("create_time", models.DateTimeField(auto_now_add=True, verbose_name="\u521b\u5efa\u65f6\u95f4")),
                ("executor", models.CharField(max_length=32, verbose_name="\u6267\u884c\u8005")),
                ("start_time", models.DateTimeField(blank=True, null=True, verbose_name="\u542f\u52a8\u65f6\u95f4")),
                ("finish_time", models.DateTimeField(blank=True, null=True, verbose_name="\u7ed3\u675f\u65f6\u95f4")),
                ("description", models.TextField(blank=True, null=True, verbose_name="\u63cf\u8ff0")),
                ("is_started", models.BooleanField(default=False, verbose_name="\u662f\u5426\u5df2\u7ecf\u542f\u52a8")),
                (
                    "is_finished",
                    models.BooleanField(default=False, verbose_name="\u662f\u5426\u5df2\u7ecf\u5b8c\u6210"),
                ),
                (
                    "is_deleted",
                    models.BooleanField(
                        default=False,
                        help_text="\u8868\u793a\u5f53\u524d\u5b9e\u4f8b\u662f\u5426\u5220\u9664",
                        verbose_name="\u662f\u5426\u5df2\u7ecf\u5220\u9664",
                    ),
                ),
            ],
            options={
                "ordering": ["-create_time"],
                "verbose_name": "Pipeline\u5b9e\u4f8b",
                "verbose_name_plural": "Pipeline\u5b9e\u4f8b",
            },
        ),
        migrations.CreateModel(
            name="PipelineTemplate",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("template_id", models.CharField(max_length=32, unique=True, verbose_name="\u6a21\u677fID")),
                (
                    "name",
                    models.CharField(
                        default="\u9ed8\u8ba4\u6a21\u677f", max_length=64, verbose_name="\u6a21\u677f\u540d\u79f0"
                    ),
                ),
                ("create_time", models.DateTimeField(auto_now_add=True, verbose_name="\u521b\u5efa\u65f6\u95f4")),
                ("creator", models.CharField(max_length=32, verbose_name="\u521b\u5efa\u8005")),
                ("description", models.TextField(blank=True, null=True, verbose_name="\u63cf\u8ff0")),
                ("editor", models.CharField(blank=True, max_length=32, null=True, verbose_name="\u4fee\u6539\u8005")),
                ("edit_time", models.DateTimeField(auto_now=True, verbose_name="\u4fee\u6539\u65f6\u95f4")),
                (
                    "is_deleted",
                    models.BooleanField(
                        default=False,
                        help_text="\u8868\u793a\u5f53\u524d\u6a21\u677f\u662f\u5426\u5220\u9664",
                        verbose_name="\u662f\u5426\u5220\u9664",
                    ),
                ),
            ],
            options={
                "ordering": ["-edit_time"],
                "verbose_name": "Pipeline\u6a21\u677f",
                "verbose_name_plural": "Pipeline\u6a21\u677f",
            },
        ),
        migrations.CreateModel(
            name="Snapshot",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                (
                    "md5sum",
                    models.CharField(
                        max_length=32, unique=True, verbose_name="\u5feb\u7167\u5b57\u7b26\u4e32\u7684md5sum"
                    ),
                ),
                ("create_time", models.DateTimeField(auto_now_add=True, verbose_name="\u521b\u5efa\u65f6\u95f4")),
                ("data", pipeline.models.CompressJSONField(blank=True, null=True)),
            ],
            options={
                "ordering": ["-id"],
                "verbose_name": "\u6a21\u677f\u5feb\u7167",
                "verbose_name_plural": "\u6a21\u677f\u5feb\u7167",
            },
        ),
        migrations.CreateModel(
            name="VariableModel",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("code", models.CharField(max_length=255, unique=True, verbose_name="\u53d8\u91cf\u7f16\u7801")),
                ("status", models.BooleanField(default=True, verbose_name="\u53d8\u91cf\u662f\u5426\u53ef\u7528")),
            ],
            options={
                "ordering": ["-id"],
                "verbose_name": "lazy \u53d8\u91cf",
                "verbose_name_plural": "lazy \u53d8\u91cf",
            },
        ),
        migrations.AddField(
            model_name="pipelinetemplate",
            name="snapshot",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="pipeline.Snapshot",
                verbose_name="\u6a21\u677f\u7ed3\u6784\u6570\u636e",
            ),
        ),
        migrations.AddField(
            model_name="pipelineinstance",
            name="execution_snapshot",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="execution_snapshot",
                to="pipeline.Snapshot",
                verbose_name="\u7528\u4e8e\u5b9e\u4f8b\u6267\u884c\u7684\u7ed3\u6784\u6570\u636e",
            ),
        ),
        migrations.AddField(
            model_name="pipelineinstance",
            name="snapshot",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="snapshot",
                to="pipeline.Snapshot",
                verbose_name="\u5b9e\u4f8b\u7ed3\u6784\u6570\u636e",
            ),
        ),
        migrations.AddField(
            model_name="pipelineinstance",
            name="template",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="pipeline.PipelineTemplate",
                verbose_name="Pipeline\u6a21\u677f",
            ),
        ),
    ]



# Generated by Django 2.2.24 on 2022-01-12 14:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pipeline', '0031_auto_20210624_2317'),
    ]

    operations = [
        migrations.AddField(
            model_name='templatescheme',
            name='subprocess_scheme_relation',
            field=models.ManyToManyField(to='pipeline.TemplateRelationship', verbose_name='子流程节点引用执行方案的关系'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-08-13 04:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pipeline", "0024_auto_20200213_0738"),
    ]

    operations = [
        migrations.AlterField(
            model_name="snapshot",
            name="md5sum",
            field=models.CharField(db_index=True, max_length=32, verbose_name="快照字符串的md5sum"),
        ),
    ]
